@@ -1,6 +1,6 @@
+from django.core.exceptions import ImproperlyConfigured
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.conf import settings
 
 from . import conf
 from .api import send_gcm_message
@@ -11,6 +11,12 @@ def get_device_model():
     return load_object(conf.GCM_DEVICE_MODEL)
 
 
+def get_api_key():
+    if not conf.GCM_APIKEY:
+        raise ImproperlyConfigured("You haven't set the 'GCM_APIKEY' setting yet.")
+    return conf.GCM_APIKEY
+
+
 class AbstractDevice(models.Model):
 
     name = models.CharField(max_length=255, verbose_name=_("Name"), blank=True, null=True)
@@ -31,7 +37,7 @@ class AbstractDevice(models.Model):
 
     def send_message(self, msg, collapse_key="message"):
         return send_gcm_message(
-            api_key=settings.GCM_APIKEY,
+            api_key=get_api_key(),
             regs_id=[self.reg_id],
             data={'msg': msg},
             collapse_key=collapse_key)
